@@ -11,7 +11,7 @@ use HTML::Parser 3.08;
 require 5.005;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.20';
+$VERSION = '0.21';
 @ISA = qw(HTML::Parser);
 
 sub new {
@@ -356,7 +356,7 @@ HTML::FillInForm is now integrated with Apache::ASP.  To activate, use
 
 =head1 VERSION
 
-This documentation describes HTML::FillInForm module version 0.20.
+This documentation describes HTML::FillInForm module version 0.21.
 
 =head1 SECURITY
 
@@ -404,7 +404,7 @@ Fixes, Bug Reports, Docs have been generously provided by:
   Tom Lancaster
   Martin H Sluka
   Mark Stosberg
-  Jeff Anderson
+  Trevor Schellhorn
   Jim Miner
   Paul Lindner
   Andrew Creer
